pub enum DecodeError {
InputTooLarge {
actual: usize,
maximum: usize,
},
NotAnimatedWebp,
DecoderOptionsInitialization,
DecoderCreation,
DecoderInfo,
InvalidAnimationInfo,
FrameSizeOverflow,
LimitExceeded {
limit: &'static str,
actual: u64,
maximum: u64,
},
FrameDecode,
InvalidTimestamp,
}Expand description
Failure to create or read an animation decoder.
Variants
InputTooLarge
The input is larger than the configured byte limit.
Fields
NotAnimatedWebp
The input is a valid WebP image but does not contain animation data.
DecoderOptionsInitialization
libwebp could not initialize its decoder options.
DecoderCreation
libwebp could not create an animation decoder.
DecoderInfo
libwebp could not provide animation metadata.
InvalidAnimationInfo
The animation metadata could not be represented by this crate’s types.
FrameSizeOverflow
A canvas or frame size overflowed the host address space.
LimitExceeded
A configured resource limit was exceeded.
Fields
FrameDecode
libwebp failed to decode the next frame.
InvalidTimestamp
Frame timestamps were not monotonic or could not be accumulated.