EncoderConfigOverrides

Struct EncoderConfigOverrides 

pub struct EncoderConfigOverrides {
    pub quality: Option<f32>,
    pub lossless: Option<bool>,
    pub method: Option<u8>,
    pub use_sharp_yuv: Option<bool>,
    pub autofilter: Option<bool>,
    pub alpha_quality: Option<u8>,
    pub preprocessing: Option<u8>,
    pub thread_level: Option<bool>,
    pub filter_strength: Option<i32>,
    pub filter_sharpness: Option<i32>,
    pub filter_type: Option<i32>,
}
Optional per-frame configuration passed to libwebp.

Applications should choose their product policy explicitly. None means to retain the corresponding value supplied by WebPConfig::new().

Fields

quality: Option<f32>

Lossy quality in libwebp’s inclusive 0.0..=100.0 range.

lossless: Option<bool>

Encode frames losslessly when Some(true) or lossy when Some(false).

method: Option<u8>

libwebp encoding method in the inclusive 0..=6 range.

use_sharp_yuv: Option<bool>

Use libwebp’s high-quality (and slower) RGB-to-YUV conversion.

autofilter: Option<bool>

Let libwebp select the in-loop filter strength per frame.

alpha_quality: Option<u8>

Alpha compression quality in the inclusive 0..=100 range.

preprocessing: Option<u8>

libwebp preprocessing mode (0 disables it). Mode 2 introduces dithering, which can create temporal noise in animation.

thread_level: Option<bool>

Ask libwebp to use its internal encoder threading when available.

filter_strength: Option<i32>

Fixed in-loop filtering settings.

filter_sharpness: Option<i32>

Fixed in-loop filter sharpness in libwebp’s 0..=7 range.

filter_type: Option<i32>

In-loop filter type in libwebp’s 0..=1 range.