pub enum TranscodeError {
Decode(DecodeError),
Resize(ResizeError),
Encode(EncodeError),
DurationOverflow,
FrameCountOverflow,
FrameCountMismatch {
decoded: u32,
declared: u32,
},
}Expand description
Failure while transcoding an animated WebP sequence.
Variants
Decode(DecodeError)
The source animation could not be decoded.
Resize(ResizeError)
The source or destination resize operation could not be created/applied.
Encode(EncodeError)
The destination encoder could not be created or finished.
DurationOverflow
The accumulated frame durations overflowed Duration.
FrameCountOverflow
The number of processed frames overflowed u32.
FrameCountMismatch
The decoder produced a different number of frames than the source metadata declared.